@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::str::str_to_isbn13;
 
 our $DATE = '2018-08-23'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -32,7 +32,7 @@ sub coerce {
         "do { my \$digits = $dt; \$digits =~ s/[^0-9Xx]//g; ",
         "my \$res; ",
         "{ ",
-        "  if (length \$digits == 10) { \$digits = Algorithm::CheckDigits::CheckDigits('ean')->complete('978' . substr(\$digits, 0, 9)); \$res = [undef, \$digits]; last } ",
+        "  if (length \$digits == 10) { \$digits = Algorithm::CheckDigits::CheckDigits('ean')->complete('978' . substr(\$digits, 0, 9)); \$res = [undef, \$digits]; last } ", # convert from ISBN 10
         "  if (length \$digits != 13) { \$res = ['ISBN 13 must have 13 digits']; last } ",
         "  unless (Algorithm::CheckDigits::CheckDigits('ean')->is_valid(\$digits)) { \$res = ['Invalid checksum digit']; last } ",
         "  \$res = [undef, \$digits]; ",
@@ -58,7 +58,7 @@ Data::Sah::Coerce::perl::str::str_to_isbn13 - Check and format ISBN 13 number fr
 
 =head1 VERSION
 
-This document describes version 0.002 of Data::Sah::Coerce::perl::str::str_to_isbn13 (from Perl distribution Sah-Schemas-ISBN), released on 2018-08-23.
+This document describes version 0.003 of Data::Sah::Coerce::perl::str::str_to_isbn13 (from Perl distribution Sah-Schemas-ISBN), released on 2018-08-23.
 
 =head1 DESCRIPTION
 
@@ -74,7 +74,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-ISBN>.
+Source repository is at L<https://github.com///u1@198.58.100.202:/home/u1/repos/perl-Sah-Schemas-ISBN>.
 
 =head1 BUGS
 
