@@ -1,7 +1,7 @@
 package Sah::Schemas::ISBN;
 
 our $DATE = '2018-08-23'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: Various Sah schemas related to ISBN (International Standard Book Number)
@@ -18,12 +18,21 @@ Sah::Schemas::ISBN - Various Sah schemas related to ISBN (International Standard
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schemas::ISBN (from Perl distribution Sah-Schemas-ISBN), released on 2018-08-23.
+This document describes version 0.003 of Sah::Schemas::ISBN (from Perl distribution Sah-Schemas-ISBN), released on 2018-08-23.
 
 =head1 SAH SCHEMAS
 
 =over
 
+=item * L<isbn|Sah::Schema::isbn>
+
+ISBN 10 or ISBN 13 number.
+
+Nondigits [^0-9Xx] will be removed during coercion.
+
+Checksum digit must be valid.
+
+
 =item * L<isbn10|Sah::Schema::isbn10>
 
 ISBN 10 number.
@@ -55,7 +64,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-ISBN>.
+Source repository is at L<https://github.com///u1@198.58.100.202:/home/u1/repos/perl-Sah-Schemas-ISBN>.
 
 =head1 BUGS
 
